#!/bin/sh

# Run Scalasca analyzer (scan) on available test executables

# defaults
V=${V:-""} # set for verbose commentary
N=${N:-""} # set to show but not run scans
TESTS=${TESTS:-"ctest ftest"}
INSTS=${INSTS:-"auto pomp epik elg vt"}
MODES=${MODES:-"mpi hyb"}
SCANS=${SCANS:-"-s -t"}
PROCS=${PROCS:-4}

SCAN="scan"
LAUNCH="mpiexec -np $PROCS"

echo "$0: Running tests with: $SCAN $LAUNCH"
echo TESTS=\"$TESTS\" INSTS=\"$INSTS\" MODES=\"$MODES\" SCANS=\"$SCANS\"
if [ -n "$OMP_NUM_THREADS" ]; then
    echo "(OMP_NUM_THREADS=$OMP_NUM_THREADS)"
else
    echo "(OMP_NUM_THREADS not set)"
fi

for TEST in $TESTS
do
    for INST in $INSTS
    do
        BASE=$TEST
        if [ $INST != "auto" ]; then
            BASE=$TEST-$INST
        fi
        for MODE in $MODES
        do
            PROG=$BASE-$MODE
            if [ -x $PROG ]; then
                for SCANO in $SCANS
                do
                    echo "$SCAN $SCANO $LAUNCH $PROG"
                    [ -z "$N" ] && eval "$SCAN $SCANO $LAUNCH ./$PROG"
                done
            else
                [ -n "$V" ] && echo "$0: Skipping unavailable $PROG"
            fi
        done
    done
done

echo "$0: Completed tests with: $SCAN $LAUNCH"

